ConstantQualityValueRateControl class

Constant-quality via explicit native CRF/QP numeric. Advanced; codec-specific valid ranges apply — see QualityMapper.validRangeFor.

Inheritance

Constructors

ConstantQualityValueRateControl(double value)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited