HardwareCapabilities class

Snapshot of device encode/decode capabilities. Queried via native MediaCodecList / VideoToolbox.

Constructors

HardwareCapabilities({required bool supportsHardwareH264Encode, required bool supportsHardwareH265Encode, required bool supportsHardwareAv1Encode, required bool supportsHardwareVp9Encode, required bool supportsHardwareDecode, required String platform, Map<String, dynamic> details = const {}})
const
HardwareCapabilities.fromMap(Map<String, dynamic> map)
factory

Properties

details → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
platform → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
supportsHardwareAv1 → bool
no setter
supportsHardwareAv1Encode → bool
final
supportsHardwareDecode → bool
final
supportsHardwareH264 → bool
no setter
supportsHardwareH264Encode → bool
final
supportsHardwareH265 → bool
no setter
supportsHardwareH265Encode → bool
final
supportsHardwareVp9Encode → bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
supportsEncodeFor(String codecId) → bool
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited