ImageCompressionOptions class

Constructors

ImageCompressionOptions({int quality = 82, int? maxWidth, int? maxHeight, ImageFormat format = ImageFormat.auto, bool preserveExif = false, bool preserveAlpha = true, bool progressive = false, bool keepOriginalIfSmaller = true, bool overwriteExisting = false})
const

Properties

format → ImageFormat
final
hashCode → int
The hash code for this object.
no setterinherited
keepOriginalIfSmaller → bool
final
maxHeight → int?
final
maxWidth → int?
final
overwriteExisting → bool
final
preserveAlpha → bool
final
preserveExif → bool
final
progressive → bool
final
quality → int
0..100 — perceptual quality (higher = larger & better). 82 is a balanced default.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
validate() → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited