JobHandle class

Internal convenience used by platform impls that back jobs with EventChannel + MethodChannel.

Constructors

JobHandle(String id, StreamController<CompressionProgress> progressController, Completer<CompressionResult> resultCompleter)

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
final
progressController → StreamController<CompressionProgress>
final
resultCompleter → Completer<CompressionResult>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

complete(CompressionResult r) → void
fail(Object e, [StackTrace? st]) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited