OutOfMemoryException class

Inheritance

Constructors

OutOfMemoryException(String message, {String? nativeCode, String? nativeMessage})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isRecoverable → bool
finalinherited
message → String
finalinherited
nativeCode → String?
finalinherited
nativeMessage → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited