RateControl class sealed
Preferred rate-control mode. Constant-quality is default (HandBrake-aligned).
Constructors
- RateControl.averageBitrate(int bitrateKbps, {bool twoPass})
-
constfactory
- RateControl.constantQuality(VideoQuality quality)
-
constfactory
- RateControl.constantQualityValue(double value)
-
constfactory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited