VideoContainer enum
Container. MP4 is default; MKV used where Opus/AV1 passthrough prefers it.
Values
- mp4 → const VideoContainer
-
const VideoContainer('mp4', '.mp4') - mov → const VideoContainer
-
const VideoContainer('mov', '.mov') - mkv → const VideoContainer
-
const VideoContainer('mkv', '.mkv')
Properties
- extension → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromId(
String id) → VideoContainer
Constants
-
values
→ const List<
VideoContainer> - A constant List of the values in this enum, in order of their declaration.